Gallery
========

Here is a gallery of examples of `figanos`.
Go to the examples to see how to generate these figures.

Timeseries
^^^^^^^^^^^
Full code in the `Timeseries notebook <notebooks/figanos_timeseries.ipynb>`_.

.. image:: _static/_gallery/basic_timeseries.png
    :width: 40%
    :target: notebooks/figanos_timeseries.html#Basic-timeseries

.. image:: _static/_gallery/ensemble_timeseries.png
    :width: 40%
    :target: notebooks/figanos_timeseries.html#Ensembles

Maps
^^^^
Full code in the `Maps notebook <notebooks/figanos_maps.ipynb>`_.

.. image:: _static/_gallery/basic_map.png
    :width: 30%
    :target: notebooks/figanos_maps.html#Gridded-Data-on-Maps

.. image:: _static/_gallery/station_map.png
    :width: 30%
    :target: notebooks/figanos_maps.html#Station-Data-on-Maps

.. image:: _static/_gallery/station+grid_map.png
    :width: 30%
    :target: notebooks/figanos_maps.html#Station-Data-on-Maps

.. image:: _static/_gallery/hatch_map.png
    :width: 30%
    :target: notebooks/figanos_maps.html#Hatching-on-Maps

.. image:: _static/_gallery/gdf_map.png
    :width: 30%
    :target: notebooks/figanos_maps.html#GeoDataFrame-on-Maps

.. image:: _static/_gallery/gdf2_map.png
    :width: 30%
    :target: notebooks/figanos_maps.html#GeoDataFrame-on-Maps

Miscellaneous
^^^^^^^^^^^^^
Full code in the `Miscellaneous notebook <notebooks/figanos_misc.ipynb>`_.

.. image:: _static/_gallery/stripes.png
    :width: 30%
    :target: notebooks/figanos_misc.html#Climate-Stripes

.. image:: _static/_gallery/violin.png
    :width: 30%
    :target: notebooks/figanos_misc.html#Violin-Plots

.. image:: _static/_gallery/heatmap.png
    :width: 30%
    :target: notebooks/figanos_misc.html#Heatmaps

.. image:: _static/_gallery/triangle1.png
    :width: 30%
    :target: notebooks/figanos_misc.html#Triangle-heatmaps

.. image:: _static/_gallery/triangle2.png
    :width: 30%
    :target: notebooks/figanos_misc.html#Triangle-Heatmaps

.. image:: _static/_gallery/taylor.png
    :width: 30%
    :target: notebooks/figanos_misc.html#Taylor-Diagrams

.. image:: _static/_gallery/partition.png
    :width: 30%
    :target: notebooks/figanos_misc.html#Partition-plots

.. image:: _static/_gallery/logo.png
    :width: 30%
    :target: notebooks/figanos_misc.html#Logos

Multiple plots
^^^^^^^^^^^^^^

Full code in the `Multiple plots notebook <notebooks/figanos_multiplots.ipynb>`_.

.. image:: _static/_gallery/multiple.png
    :width: 50%
    :target: notebooks/figanos_multiplots.html#Maps
